Module and Class Hierarchies

[show private | hide private]
[frames | no frames]

## Module Hierarchy

- `RDFFormats`: General support for conversion of data to RDF information.
  - `Format`: Constants for parsing and writing.
  - `FormatWriters`: Format writer classes.
  - `Store`: Storage of nodes according to general RDFFormats conventions.
  - `Writers`: Writer classes.

## Class Hierarchy

- `RDFFormats.FormatWriters.DOMWriter`: A DOM document writer.
- `RDFFormats.Store.AbstractHandler`: WebOrganiser-compatible handler methods.
  - `RDFFormats.Store.Store`: A store class providing, in each instance, a wrapper around an underlying store, convenience attributes based on namespaces from the Format module and node types from the underlying store implementation, and a selection of higher-level operations relevant to parsing and writing.
- `RDFFormats.Store.AbstractStore`: The interface employed by the RDFCalendar.Parsers classes.
  - `RDFFormats.Store.Store`: A store class providing, in each instance, a wrapper around an underlying store, convenience attributes based on namespaces from the Format module and node types from the underlying store implementation, and a selection of higher-level operations relevant to parsing and writing.
- `RDFFormats.Writers.Writer`: A writer class which, acting as a visitor on nodes in a store, employs a format writer in order to produce actual output.

Generated by Epydoc 2.1 on Wed Jan 10 22:34:07 2007 | http://epydoc.sf.net